OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Denegat (permís heretat)",
    "Allowed (Inherited permission)" : "Permès (permís heretat)",
    "Denied" : "Denegat",
    "Allowed" : "Permès",
    "Access denied" : "Accés denegat",
    "Inherit permission" : "Hereta el permís",
    "Deny" : "Denega",
    "Allow" : "Permet",
    "Group" : "Grup",
    "Team" : "Equip",
    "Read" : "Llegeix",
    "Write" : "Escriu",
    "Create" : "Crea",
    "Delete" : "Suprimeix",
    "Share" : "Comparteix",
    "You" : "Vós",
    "Remove access rule" : "Suprimeix la regla d'accés",
    "Select a user or group" : "Seleccioneu un usuari o un grup",
    "Add group" : "Afegeix un grup",
    "Default" : "Per defecte",
    "Unlimited" : "Il·limitat",
    "Delete \"{folderName}\"?" : "Suprimir \"{folderName}\"?",
    "Folder name" : "Nom de la carpeta",
    "Quota" : "Quota",
    "Advanced Permissions" : "Permisos avançats",
    "Previous" : "Anterior",
    "Next" : "Següent",
    "User" : "Usuari",
    "Unknown" : "Desconegut",
    "None" : "Només una vegada",
    "{size} used" : "{size} en ús",
    "Unset" : "No definit"
},
"nplurals=2; plural=(n != 1);");
